Moved the if1632/signal.c stuff into loader/signal.c, adapted function
pointers for wine_debug and INSTR_EmulateInstruction.

diff --git a/miscemu/instr.c b/miscemu/instr.c
index 8b4877b..577644c 100644
--- a/miscemu/instr.c
+++ b/miscemu/instr.c
@@ -323,13 +323,6 @@
     SEGPTR gpHandler;
     BYTE *instr;
 
-    /* Check for page-fault */
-
-#if defined(TRAP_sig) && defined(CR2_sig)
-    if (TRAP_sig(context) == 0x0e
-        && VIRTUAL_HandleFault( (LPVOID)CR2_sig(context) )) return TRUE;
-#endif
-
     long_op = long_addr = IS_SEL_32(context,CS_sig(context));
     instr = (BYTE *)MK_PTR(context,CS_sig(context),EIP_sig(context));
     if (!instr) return FALSE;
diff --git a/miscemu/main.c b/miscemu/main.c
index cda9fca..31b4b20 100644
--- a/miscemu/main.c
+++ b/miscemu/main.c
@@ -32,10 +32,6 @@
     /* Initialize relay code */
     if (!RELAY_Init()) return FALSE;
 
-    /* Initialize signal handling */
-    if (!SIGNAL_InitEmulator()) return FALSE;
-    SIGNAL_Reinit=SIGNAL_InitEmulator;
-
     /* Create the Win16 printer driver */
     if (!WIN16DRV_Init()) return FALSE;
 
@@ -150,8 +146,11 @@
         }
     }
 
-    /* Set up debugger callback routines */
-    ctx_debug_call = ctx_debug;
+    /* Set up debugger/instruction emulation callback routines */
+    ctx_debug_call		= ctx_debug;
+    fnWINE_Debugger		= wine_debug;
+    fnINSTR_EmulateInstruction	= INSTR_EmulateInstruction;
+
     if (Options.debug) 
         TASK_AddTaskEntryBreakpoint = DEBUG_AddTaskEntryBreakpoint;
 
@@ -177,4 +176,3 @@
     MSG( "main: Should never happen: returned from TASK_StartTask()\n" );
     return 0;
 }
-